@@ -21,3 +21,9 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         self, service, dict_args, secret_tool, config_tool
     ):
         "get all findings and exclusions from vulnerability management platform"
+
+    @abstractmethod
+    def get_active_engagements(
+        self, engagement_name, dict_args, secret_tool, config_tool
+    ):
+        "get_active_engagements"
