@@ -1,5 +1,5 @@
 from abc import ABCMeta, abstractmethod
-
+from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.DeserializeConfigTool import DeserializeConfigTool
 
 class ToolGateway(metaclass=ABCMeta):
     @abstractmethod
@@ -8,8 +8,10 @@ class ToolGateway(metaclass=ABCMeta):
     @abstractmethod
     def run_tool_secret_scan(self,
                             files_pullrequest: dict,
-                            exclude_path: dict,
                             agent_os: str,
                             agent_work_folder: str,
-                            num_threads: int) -> str:
+                            repository_name: str,
+                            config_tool: DeserializeConfigTool,
+                            secret_tool,
+                            secret_external_checks) -> str:
         "run tool secret scan"
\ No newline at end of file
