@@ -7,6 +7,13 @@ import concurrent.futures
 from devsecops_engine_tools.engine_sast.engine_secret.src.domain.model.gateway.tool_gateway import (
     ToolGateway,
 )
+from devsecops_engine_tools.engine_utilities.github.infrastructure.github_api import (
+    GithubApi,
+)
+from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
+from devsecops_engine_tools.engine_utilities import settings
+
+logger = MyLogger.__call__(**settings.SETTING_LOGGER).get_logger()
 
 result = []
 
@@ -40,25 +47,42 @@ class TrufflehogRun(ToolGateway):
     def run_tool_secret_scan(
         self,
         files_commits,
-        exclude_paths,
         agent_os,
         agent_work_folder,
-        num_threads
+        repository_name,
+        config_tool,
+        secret_tool,
+        secret_external_checks
     ):
         trufflehog_command = "trufflehog"
         if "Windows" in agent_os:
             trufflehog_command = "C:/Trufflehog/bin/trufflehog.exe"
         with open(f"{agent_work_folder}/excludedPath.txt", "w") as file:
-            file.write("\n".join(exclude_paths))
+            file.write("\n".join(config_tool.exclude_path))
         exclude_path = f"{agent_work_folder}/excludedPath.txt"
         include_paths = self.config_include_path(files_commits, agent_work_folder)
-        with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
+        enable_custom_rules = config_tool.enable_custom_rules.lower()
+        secret = None
+        
+        if secret_tool is not None:
+            secret = secret_tool["github_token"] if "github" in secret_tool else None
+        elif secret_external_checks is not None:
+            secret = secret_external_checks.split("github:")[1] if "github" in secret_external_checks else None            
+
+        if enable_custom_rules == "true" and secret is not None:
+            self.configurate_external_checks(config_tool, secret)
+        else: #In case that remote config from tool is enable but in the args dont send any type of secrets. So dont modified command
+            enable_custom_rules == "false"
+
+        with concurrent.futures.ThreadPoolExecutor(max_workers=config_tool.number_threads) as executor:
             results = executor.map(
                 self.run_trufflehog,
                 [trufflehog_command] * len(include_paths),
                 [agent_work_folder] * len(include_paths),
                 [exclude_path] * len(include_paths),
                 include_paths,
+                [repository_name] * len(include_paths),
+                [enable_custom_rules],
             )
         findings, file_findings = self.create_file(self.decode_output(results), agent_work_folder)
         return  findings, file_findings
@@ -86,9 +110,15 @@ class TrufflehogRun(ToolGateway):
         trufflehog_command,
         agent_work_folder,
         exclude_path,
-        include_path
+        include_path,
+        repository_name,
+        enable_custom_rules
     ):
-        command = f"{trufflehog_command} filesystem {agent_work_folder} --include-paths {include_path} --exclude-paths {exclude_path} --no-verification --json"
+        command = f"{trufflehog_command} filesystem {agent_work_folder + '/' + repository_name} --include-paths {include_path} --exclude-paths {exclude_path} --no-verification --json"
+
+        if enable_custom_rules == "true":
+            command = command.replace("--no-verification --json", "--config /tmp/rules/trufflehog/custom-rules.yaml --no-verification --json")
+
         result = subprocess.run(command, capture_output=True, shell=True, text=True)
         return result.stdout.strip()
 
@@ -112,4 +142,15 @@ class TrufflehogRun(ToolGateway):
                 find["SourceMetadata"]["Data"]["Filesystem"]["file"] = where_text
                 json_str = json.dumps(find)
                 file.write(json_str + '\n')
-        return findings, file_findings
\ No newline at end of file
+        return findings, file_findings
+    
+    def configurate_external_checks(self, config_tool, secret):
+        try:
+            github_api = GithubApi(secret)
+            github_api.download_latest_release_assets(
+                config_tool.external_dir_owner,
+                config_tool.external_dir_repo,
+                "/tmp",
+            )
+        except Exception as ex:
+            logger.error(f"An error ocurred download external checks {ex}")
\ No newline at end of file
