@@ -4,6 +4,12 @@ from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.dr
 from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.driven_adapters.xray_tool.xray_deserialize_output import (
     XrayDeserializator,
 )
+from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.driven_adapters.dependency_check.dependency_check_tool import (
+    DependencyCheckTool,
+)
+from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.driven_adapters.dependency_check.dependency_check_deserialize import (
+    DependencyCheckDeserialize,
+)
 from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.entry_points.entry_point_tool import (
     init_engine_dependencies,
 )
@@ -11,9 +17,21 @@ from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.en
 
 def runner_engine_dependencies(dict_args, config_tool, secret_tool, devops_platform_gateway):
     try:
-        if config_tool["ENGINE_DEPENDENCIES"]["TOOL"] == "XRAY":
-            tool_run = XrayScan()
-            tool_deserializator = XrayDeserializator()
+        tools_mapping = {
+            "XRAY": {
+                "tool_run": XrayScan,
+                "tool_deserializator": XrayDeserializator
+            },
+            "DEPENDENCY_CHECK": {
+                "tool_run": DependencyCheckTool,
+                "tool_deserializator": DependencyCheckDeserialize
+            }
+        }
+
+        selected_tool = config_tool["ENGINE_DEPENDENCIES"]["TOOL"]
+        tool_run = tools_mapping[selected_tool]["tool_run"]()
+        tool_deserializator = tools_mapping[selected_tool]["tool_deserializator"]()
+
 
         return init_engine_dependencies(
             tool_run,
